/*
 * Copyright (c) Huawei Technologies Co., Ltd. 2020-2024. All rights reserved.
 */

#ifndef JAC_AP_EMSERVICE_EMSERVICE_SKELETON_H
#define JAC_AP_EMSERVICE_EMSERVICE_SKELETON_H

#include "ara/com/internal/skeleton/skeleton_adapter.h"
#include "ara/com/internal/skeleton/event_adapter.h"
#include "ara/com/internal/skeleton/field_adapter.h"
#include "ara/com/internal/skeleton/method_adapter.h"
#include "ara/com/crc_verification.h"
#include "jac/ap/emservice/emservice_common.h"
#include <cstdint>

namespace jac {
namespace ap {
namespace emservice {
namespace skeleton {
namespace events
{
    using TargetsInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::TargetsInfo>;
    using TargetInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::TargetInfo>;
    using RoadEdgeInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RoadEdgeInfo>;
    using LaneMarkerInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LaneMarkerInfo>;
    using RoadInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RoadInfo>;
    using RMHeaderEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMHeader>;
    using IndexEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::Index>;
    using CarPositionEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::CarPosition>;
    using LaneEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::Lane>;
    using LaneMarkerEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LaneMarker>;
    using ObjectEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::Object>;
    using RoadEdgeEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RoadEdge>;
    using NeighborLaneEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::NeighborLane>;
    using CorridorEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::Corridor>;
    using SamplingPointEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::SamplingPoint>;
    using LineColorEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LineColor>;
    using LineTypeEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LineType>;
    using ObjectLocationEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::ObjectLocation>;
    using SLPointEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::SLPoint>;
    using LaneControlEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LaneControl>;
    using LaneBoundryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LaneBoundary>;
    using LineGeometryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LineGeometry>;
    using RoadEdgeSegmentEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RoadEdgeSegment>;
    using LaneInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LaneInfo>;
    using LeftLineEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LeftLine>;
    using RightLineEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RightLine>;
    using RightRoadEdgeEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RightRoadEdge>;
    using LeftRoadEdgeEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::LeftRoadEdge>;
    using ODDInfoEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::ODDInfo>;
    using RMEgoLftLnegeometryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMEgoLftLnegeometry>;
    using RMEgoRgtLnegeometryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMEgoRgtLnegeometry>;
    using RMRdEdgeLftgeometryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMRdEdgeLftgeometry>;
    using RMRdEdgeRgtgeometryEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMRdEdgeRgtgeometry>;
    using RMSMMessageEvent = ara::com::internal::skeleton::event::EventAdapter<::dpc::RMSMMessage>;
    static constexpr ara::com::internal::EntityId EMServiceTargetsInfoEventId = 16631U; //TargetsInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceTargetInfoEventId = 28852U; //TargetInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRoadEdgeInfoEventId = 3862U; //RoadEdgeInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneMarkerInfoEventId = 51141U; //LaneMarkerInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRoadInfoEventId = 56244U; //RoadInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMHeaderEventId = 10987U; //RMHeaderEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceIndexEventId = 46526U; //IndexEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceCarPositionEventId = 37925U; //CarPositionEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneEventId = 41942U; //LaneEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneMarkerEventId = 53518U; //LaneMarkerEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceObjectEventId = 35544U; //ObjectEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRoadEdgeEventId = 62920U; //RoadEdgeEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceNeighborLaneEventId = 58173U; //NeighborLaneEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceCorridorEventId = 5591U; //CorridorEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceSamplingPointEventId = 16127U; //SamplingPointEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLineColorEventId = 62077U; //LineColorEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLineTypeEventId = 18174U; //LineTypeEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceObjectLocationEventId = 29095U; //ObjectLocationEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceSLPointEventId = 33687U; //SLPointEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneControlEventId = 8773U; //LaneControlEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneBoundryEventId = 32933U; //LaneBoundryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLineGeometryEventId = 1163U; //LineGeometryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRoadEdgeSegmentEventId = 64294U; //RoadEdgeSegmentEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLaneInfoEventId = 58013U; //LaneInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLeftLineEventId = 28186U; //LeftLineEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRightLineEventId = 10371U; //RightLineEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRightRoadEdgeEventId = 35493U; //RightRoadEdgeEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceLeftRoadEdgeEventId = 5664U; //LeftRoadEdgeEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceODDInfoEventId = 30927U; //ODDInfoEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMEgoLftLnegeometryEventId = 10719U; //RMEgoLftLnegeometryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMEgoRgtLnegeometryEventId = 64259U; //RMEgoRgtLnegeometryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMRdEdgeLftgeometryEventId = 36597U; //RMRdEdgeLftgeometryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMRdEdgeRgtgeometryEventId = 35832U; //RMRdEdgeRgtgeometryEvent_event_hash
    static constexpr ara::com::internal::EntityId EMServiceRMSMMessageEventId = 52585U; //RMSMMessageEvent_event_hash
}

namespace methods
{
}

namespace fields
{
}

class EMServiceSkeleton {
private:
    std::unique_ptr<ara::com::internal::skeleton::SkeletonAdapter> skeletonAdapter;
    void ConstructSkeleton(const ara::com::MethodCallProcessingMode mode)
    {
        if (mode == ara::com::MethodCallProcessingMode::kEvent) {
            if (!(skeletonAdapter->SetMethodThreadNumber(skeletonAdapter->GetMethodThreadNumber(0U), 1024U))) {
#ifndef NOT_SUPPORT_EXCEPTIONS
                ara::core::ErrorCode errorcode(ara::com::ComErrc::kNetworkBindingFailure);
                throw ara::com::ComException(std::move(errorcode));
#else
                std::cerr << "Error: Not support exception, create skeleton failed!" << std::endl;
#endif
            }
        }
        const ara::core::Result<void> resultTargetsInfoEvent = TargetsInfoEvent.Initialize();
        ThrowError(resultTargetsInfoEvent);
        const ara::core::Result<void> resultTargetInfoEvent = TargetInfoEvent.Initialize();
        ThrowError(resultTargetInfoEvent);
        const ara::core::Result<void> resultRoadEdgeInfoEvent = RoadEdgeInfoEvent.Initialize();
        ThrowError(resultRoadEdgeInfoEvent);
        const ara::core::Result<void> resultLaneMarkerInfoEvent = LaneMarkerInfoEvent.Initialize();
        ThrowError(resultLaneMarkerInfoEvent);
        const ara::core::Result<void> resultRoadInfoEvent = RoadInfoEvent.Initialize();
        ThrowError(resultRoadInfoEvent);
        const ara::core::Result<void> resultRMHeaderEvent = RMHeaderEvent.Initialize();
        ThrowError(resultRMHeaderEvent);
        const ara::core::Result<void> resultIndexEvent = IndexEvent.Initialize();
        ThrowError(resultIndexEvent);
        const ara::core::Result<void> resultCarPositionEvent = CarPositionEvent.Initialize();
        ThrowError(resultCarPositionEvent);
        const ara::core::Result<void> resultLaneEvent = LaneEvent.Initialize();
        ThrowError(resultLaneEvent);
        const ara::core::Result<void> resultLaneMarkerEvent = LaneMarkerEvent.Initialize();
        ThrowError(resultLaneMarkerEvent);
        const ara::core::Result<void> resultObjectEvent = ObjectEvent.Initialize();
        ThrowError(resultObjectEvent);
        const ara::core::Result<void> resultRoadEdgeEvent = RoadEdgeEvent.Initialize();
        ThrowError(resultRoadEdgeEvent);
        const ara::core::Result<void> resultNeighborLaneEvent = NeighborLaneEvent.Initialize();
        ThrowError(resultNeighborLaneEvent);
        const ara::core::Result<void> resultCorridorEvent = CorridorEvent.Initialize();
        ThrowError(resultCorridorEvent);
        const ara::core::Result<void> resultSamplingPointEvent = SamplingPointEvent.Initialize();
        ThrowError(resultSamplingPointEvent);
        const ara::core::Result<void> resultLineColorEvent = LineColorEvent.Initialize();
        ThrowError(resultLineColorEvent);
        const ara::core::Result<void> resultLineTypeEvent = LineTypeEvent.Initialize();
        ThrowError(resultLineTypeEvent);
        const ara::core::Result<void> resultObjectLocationEvent = ObjectLocationEvent.Initialize();
        ThrowError(resultObjectLocationEvent);
        const ara::core::Result<void> resultSLPointEvent = SLPointEvent.Initialize();
        ThrowError(resultSLPointEvent);
        const ara::core::Result<void> resultLaneControlEvent = LaneControlEvent.Initialize();
        ThrowError(resultLaneControlEvent);
        const ara::core::Result<void> resultLaneBoundryEvent = LaneBoundryEvent.Initialize();
        ThrowError(resultLaneBoundryEvent);
        const ara::core::Result<void> resultLineGeometryEvent = LineGeometryEvent.Initialize();
        ThrowError(resultLineGeometryEvent);
        const ara::core::Result<void> resultRoadEdgeSegmentEvent = RoadEdgeSegmentEvent.Initialize();
        ThrowError(resultRoadEdgeSegmentEvent);
        const ara::core::Result<void> resultLaneInfoEvent = LaneInfoEvent.Initialize();
        ThrowError(resultLaneInfoEvent);
        const ara::core::Result<void> resultLeftLineEvent = LeftLineEvent.Initialize();
        ThrowError(resultLeftLineEvent);
        const ara::core::Result<void> resultRightLineEvent = RightLineEvent.Initialize();
        ThrowError(resultRightLineEvent);
        const ara::core::Result<void> resultRightRoadEdgeEvent = RightRoadEdgeEvent.Initialize();
        ThrowError(resultRightRoadEdgeEvent);
        const ara::core::Result<void> resultLeftRoadEdgeEvent = LeftRoadEdgeEvent.Initialize();
        ThrowError(resultLeftRoadEdgeEvent);
        const ara::core::Result<void> resultODDInfoEvent = ODDInfoEvent.Initialize();
        ThrowError(resultODDInfoEvent);
        const ara::core::Result<void> resultRMEgoLftLnegeometryEvent = RMEgoLftLnegeometryEvent.Initialize();
        ThrowError(resultRMEgoLftLnegeometryEvent);
        const ara::core::Result<void> resultRMEgoRgtLnegeometryEvent = RMEgoRgtLnegeometryEvent.Initialize();
        ThrowError(resultRMEgoRgtLnegeometryEvent);
        const ara::core::Result<void> resultRMRdEdgeLftgeometryEvent = RMRdEdgeLftgeometryEvent.Initialize();
        ThrowError(resultRMRdEdgeLftgeometryEvent);
        const ara::core::Result<void> resultRMRdEdgeRgtgeometryEvent = RMRdEdgeRgtgeometryEvent.Initialize();
        ThrowError(resultRMRdEdgeRgtgeometryEvent);
        const ara::core::Result<void> resultRMSMMessageEvent = RMSMMessageEvent.Initialize();
        ThrowError(resultRMSMMessageEvent);
    }

    EMServiceSkeleton& operator=(const EMServiceSkeleton&) = delete;

    static void ThrowError(const ara::core::Result<void>& result)
    {
        if (!(result.HasValue())) {
#ifndef NOT_SUPPORT_EXCEPTIONS
            ara::core::ErrorCode errorcode(result.Error());
            throw ara::com::ComException(std::move(errorcode));
#else
            std::cerr << "Error: Not support exception, create skeleton failed!" << std::endl;
#endif
        }
    }
public:
    class ConstructionToken {
    public:
        explicit ConstructionToken(const ara::com::InstanceIdentifier& instanceId,
            const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
            : processMode(mode),
              ptr(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceId, mode)),
              TargetsInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              TargetInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RoadEdgeInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneMarkerInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RoadInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMHeaderEvent(ptr->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              IndexEvent(ptr->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              CarPositionEvent(ptr->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneEvent(ptr->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneMarkerEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              ObjectEvent(ptr->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              NeighborLaneEvent(ptr->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              CorridorEvent(ptr->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              SamplingPointEvent(ptr->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LineColorEvent(ptr->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LineTypeEvent(ptr->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              ObjectLocationEvent(ptr->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              SLPointEvent(ptr->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneControlEvent(ptr->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneBoundryEvent(ptr->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LineGeometryEvent(ptr->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RoadEdgeSegmentEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LaneInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LeftLineEvent(ptr->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RightLineEvent(ptr->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RightRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              LeftRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              ODDInfoEvent(ptr->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMEgoLftLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMEgoRgtLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMRdEdgeLftgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMRdEdgeRgtgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
              RMSMMessageEvent(ptr->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId){
        }

        explicit ConstructionToken(const ara::core::InstanceSpecifier& instanceSpec,
            const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
            : processMode(mode),
              ptr(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec, mode)),
              TargetsInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              TargetInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RoadEdgeInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneMarkerInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RoadInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMHeaderEvent(ptr->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              IndexEvent(ptr->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              CarPositionEvent(ptr->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneEvent(ptr->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneMarkerEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              ObjectEvent(ptr->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              NeighborLaneEvent(ptr->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              CorridorEvent(ptr->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              SamplingPointEvent(ptr->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LineColorEvent(ptr->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LineTypeEvent(ptr->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              ObjectLocationEvent(ptr->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              SLPointEvent(ptr->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneControlEvent(ptr->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneBoundryEvent(ptr->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LineGeometryEvent(ptr->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RoadEdgeSegmentEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LaneInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LeftLineEvent(ptr->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RightLineEvent(ptr->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RightRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              LeftRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              ODDInfoEvent(ptr->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMEgoLftLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMEgoRgtLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMRdEdgeLftgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMRdEdgeRgtgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
              RMSMMessageEvent(ptr->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec){
        }

        explicit ConstructionToken(const ara::com::InstanceIdentifierContainer instanceContainer,
            const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
            : processMode(mode),
              ptr(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer, mode)),
              TargetsInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              TargetInfoEvent(ptr->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RoadEdgeInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneMarkerInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RoadInfoEvent(ptr->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMHeaderEvent(ptr->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              IndexEvent(ptr->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              CarPositionEvent(ptr->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneEvent(ptr->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneMarkerEvent(ptr->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              ObjectEvent(ptr->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              NeighborLaneEvent(ptr->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              CorridorEvent(ptr->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              SamplingPointEvent(ptr->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LineColorEvent(ptr->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LineTypeEvent(ptr->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              ObjectLocationEvent(ptr->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              SLPointEvent(ptr->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneControlEvent(ptr->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneBoundryEvent(ptr->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LineGeometryEvent(ptr->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RoadEdgeSegmentEvent(ptr->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LaneInfoEvent(ptr->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LeftLineEvent(ptr->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RightLineEvent(ptr->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RightRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              LeftRoadEdgeEvent(ptr->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              ODDInfoEvent(ptr->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMEgoLftLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMEgoRgtLnegeometryEvent(ptr->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMRdEdgeLftgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMRdEdgeRgtgeometryEvent(ptr->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
              RMSMMessageEvent(ptr->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer){
        }

        ConstructionToken(ConstructionToken&& other)
            : processMode(std::move(other.processMode)),
              ptr(std::move(other.ptr)),
              TargetsInfoEvent(std::move(other.TargetsInfoEvent)),
              TargetInfoEvent(std::move(other.TargetInfoEvent)),
              RoadEdgeInfoEvent(std::move(other.RoadEdgeInfoEvent)),
              LaneMarkerInfoEvent(std::move(other.LaneMarkerInfoEvent)),
              RoadInfoEvent(std::move(other.RoadInfoEvent)),
              RMHeaderEvent(std::move(other.RMHeaderEvent)),
              IndexEvent(std::move(other.IndexEvent)),
              CarPositionEvent(std::move(other.CarPositionEvent)),
              LaneEvent(std::move(other.LaneEvent)),
              LaneMarkerEvent(std::move(other.LaneMarkerEvent)),
              ObjectEvent(std::move(other.ObjectEvent)),
              RoadEdgeEvent(std::move(other.RoadEdgeEvent)),
              NeighborLaneEvent(std::move(other.NeighborLaneEvent)),
              CorridorEvent(std::move(other.CorridorEvent)),
              SamplingPointEvent(std::move(other.SamplingPointEvent)),
              LineColorEvent(std::move(other.LineColorEvent)),
              LineTypeEvent(std::move(other.LineTypeEvent)),
              ObjectLocationEvent(std::move(other.ObjectLocationEvent)),
              SLPointEvent(std::move(other.SLPointEvent)),
              LaneControlEvent(std::move(other.LaneControlEvent)),
              LaneBoundryEvent(std::move(other.LaneBoundryEvent)),
              LineGeometryEvent(std::move(other.LineGeometryEvent)),
              RoadEdgeSegmentEvent(std::move(other.RoadEdgeSegmentEvent)),
              LaneInfoEvent(std::move(other.LaneInfoEvent)),
              LeftLineEvent(std::move(other.LeftLineEvent)),
              RightLineEvent(std::move(other.RightLineEvent)),
              RightRoadEdgeEvent(std::move(other.RightRoadEdgeEvent)),
              LeftRoadEdgeEvent(std::move(other.LeftRoadEdgeEvent)),
              ODDInfoEvent(std::move(other.ODDInfoEvent)),
              RMEgoLftLnegeometryEvent(std::move(other.RMEgoLftLnegeometryEvent)),
              RMEgoRgtLnegeometryEvent(std::move(other.RMEgoRgtLnegeometryEvent)),
              RMRdEdgeLftgeometryEvent(std::move(other.RMRdEdgeLftgeometryEvent)),
              RMRdEdgeRgtgeometryEvent(std::move(other.RMRdEdgeRgtgeometryEvent)),
              RMSMMessageEvent(std::move(other.RMSMMessageEvent)){
        }
        ConstructionToken& operator=(ConstructionToken && other)
        {
            if (&other != this) {
                processMode = std::move(other.processMode);
                ptr = std::move(other.ptr);
                TargetsInfoEvent = std::move(other.TargetsInfoEvent);
                TargetInfoEvent = std::move(other.TargetInfoEvent);
                RoadEdgeInfoEvent = std::move(other.RoadEdgeInfoEvent);
                LaneMarkerInfoEvent = std::move(other.LaneMarkerInfoEvent);
                RoadInfoEvent = std::move(other.RoadInfoEvent);
                RMHeaderEvent = std::move(other.RMHeaderEvent);
                IndexEvent = std::move(other.IndexEvent);
                CarPositionEvent = std::move(other.CarPositionEvent);
                LaneEvent = std::move(other.LaneEvent);
                LaneMarkerEvent = std::move(other.LaneMarkerEvent);
                ObjectEvent = std::move(other.ObjectEvent);
                RoadEdgeEvent = std::move(other.RoadEdgeEvent);
                NeighborLaneEvent = std::move(other.NeighborLaneEvent);
                CorridorEvent = std::move(other.CorridorEvent);
                SamplingPointEvent = std::move(other.SamplingPointEvent);
                LineColorEvent = std::move(other.LineColorEvent);
                LineTypeEvent = std::move(other.LineTypeEvent);
                ObjectLocationEvent = std::move(other.ObjectLocationEvent);
                SLPointEvent = std::move(other.SLPointEvent);
                LaneControlEvent = std::move(other.LaneControlEvent);
                LaneBoundryEvent = std::move(other.LaneBoundryEvent);
                LineGeometryEvent = std::move(other.LineGeometryEvent);
                RoadEdgeSegmentEvent = std::move(other.RoadEdgeSegmentEvent);
                LaneInfoEvent = std::move(other.LaneInfoEvent);
                LeftLineEvent = std::move(other.LeftLineEvent);
                RightLineEvent = std::move(other.RightLineEvent);
                RightRoadEdgeEvent = std::move(other.RightRoadEdgeEvent);
                LeftRoadEdgeEvent = std::move(other.LeftRoadEdgeEvent);
                ODDInfoEvent = std::move(other.ODDInfoEvent);
                RMEgoLftLnegeometryEvent = std::move(other.RMEgoLftLnegeometryEvent);
                RMEgoRgtLnegeometryEvent = std::move(other.RMEgoRgtLnegeometryEvent);
                RMRdEdgeLftgeometryEvent = std::move(other.RMRdEdgeLftgeometryEvent);
                RMRdEdgeRgtgeometryEvent = std::move(other.RMRdEdgeRgtgeometryEvent);
                RMSMMessageEvent = std::move(other.RMSMMessageEvent);
            }
            return *this;
        }
        ConstructionToken(const ConstructionToken&) = delete;
        ConstructionToken& operator = (const ConstructionToken&) = delete;
        std::unique_ptr<ara::com::internal::skeleton::SkeletonAdapter> GetSkeletonAdapter()
        {
            return std::move(ptr);
        }
        events::TargetsInfoEvent GetTargetsInfoEvent()
        {
            return std::move(TargetsInfoEvent);
        }
        events::TargetInfoEvent GetTargetInfoEvent()
        {
            return std::move(TargetInfoEvent);
        }
        events::RoadEdgeInfoEvent GetRoadEdgeInfoEvent()
        {
            return std::move(RoadEdgeInfoEvent);
        }
        events::LaneMarkerInfoEvent GetLaneMarkerInfoEvent()
        {
            return std::move(LaneMarkerInfoEvent);
        }
        events::RoadInfoEvent GetRoadInfoEvent()
        {
            return std::move(RoadInfoEvent);
        }
        events::RMHeaderEvent GetRMHeaderEvent()
        {
            return std::move(RMHeaderEvent);
        }
        events::IndexEvent GetIndexEvent()
        {
            return std::move(IndexEvent);
        }
        events::CarPositionEvent GetCarPositionEvent()
        {
            return std::move(CarPositionEvent);
        }
        events::LaneEvent GetLaneEvent()
        {
            return std::move(LaneEvent);
        }
        events::LaneMarkerEvent GetLaneMarkerEvent()
        {
            return std::move(LaneMarkerEvent);
        }
        events::ObjectEvent GetObjectEvent()
        {
            return std::move(ObjectEvent);
        }
        events::RoadEdgeEvent GetRoadEdgeEvent()
        {
            return std::move(RoadEdgeEvent);
        }
        events::NeighborLaneEvent GetNeighborLaneEvent()
        {
            return std::move(NeighborLaneEvent);
        }
        events::CorridorEvent GetCorridorEvent()
        {
            return std::move(CorridorEvent);
        }
        events::SamplingPointEvent GetSamplingPointEvent()
        {
            return std::move(SamplingPointEvent);
        }
        events::LineColorEvent GetLineColorEvent()
        {
            return std::move(LineColorEvent);
        }
        events::LineTypeEvent GetLineTypeEvent()
        {
            return std::move(LineTypeEvent);
        }
        events::ObjectLocationEvent GetObjectLocationEvent()
        {
            return std::move(ObjectLocationEvent);
        }
        events::SLPointEvent GetSLPointEvent()
        {
            return std::move(SLPointEvent);
        }
        events::LaneControlEvent GetLaneControlEvent()
        {
            return std::move(LaneControlEvent);
        }
        events::LaneBoundryEvent GetLaneBoundryEvent()
        {
            return std::move(LaneBoundryEvent);
        }
        events::LineGeometryEvent GetLineGeometryEvent()
        {
            return std::move(LineGeometryEvent);
        }
        events::RoadEdgeSegmentEvent GetRoadEdgeSegmentEvent()
        {
            return std::move(RoadEdgeSegmentEvent);
        }
        events::LaneInfoEvent GetLaneInfoEvent()
        {
            return std::move(LaneInfoEvent);
        }
        events::LeftLineEvent GetLeftLineEvent()
        {
            return std::move(LeftLineEvent);
        }
        events::RightLineEvent GetRightLineEvent()
        {
            return std::move(RightLineEvent);
        }
        events::RightRoadEdgeEvent GetRightRoadEdgeEvent()
        {
            return std::move(RightRoadEdgeEvent);
        }
        events::LeftRoadEdgeEvent GetLeftRoadEdgeEvent()
        {
            return std::move(LeftRoadEdgeEvent);
        }
        events::ODDInfoEvent GetODDInfoEvent()
        {
            return std::move(ODDInfoEvent);
        }
        events::RMEgoLftLnegeometryEvent GetRMEgoLftLnegeometryEvent()
        {
            return std::move(RMEgoLftLnegeometryEvent);
        }
        events::RMEgoRgtLnegeometryEvent GetRMEgoRgtLnegeometryEvent()
        {
            return std::move(RMEgoRgtLnegeometryEvent);
        }
        events::RMRdEdgeLftgeometryEvent GetRMRdEdgeLftgeometryEvent()
        {
            return std::move(RMRdEdgeLftgeometryEvent);
        }
        events::RMRdEdgeRgtgeometryEvent GetRMRdEdgeRgtgeometryEvent()
        {
            return std::move(RMRdEdgeRgtgeometryEvent);
        }
        events::RMSMMessageEvent GetRMSMMessageEvent()
        {
            return std::move(RMSMMessageEvent);
        }
        ara::core::Result<void> Initialize()
        {
            ara::core::Result<void> initResult;
            do {
                if (processMode == ara::com::MethodCallProcessingMode::kEvent) {
                    if(!ptr->SetMethodThreadNumber(ptr->GetMethodThreadNumber(0U), 1024U)) {
                        ara::core::ErrorCode errorCode(ara::com::ComErrc::kNetworkBindingFailure);
                        initResult.EmplaceError(errorCode);
                        break;
                    }
                }
                initResult = TargetsInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = TargetInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RoadEdgeInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneMarkerInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RoadInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMHeaderEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = IndexEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = CarPositionEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneMarkerEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = ObjectEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RoadEdgeEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = NeighborLaneEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = CorridorEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = SamplingPointEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LineColorEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LineTypeEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = ObjectLocationEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = SLPointEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneControlEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneBoundryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LineGeometryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RoadEdgeSegmentEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LaneInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LeftLineEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RightLineEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RightRoadEdgeEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = LeftRoadEdgeEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = ODDInfoEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMEgoLftLnegeometryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMEgoRgtLnegeometryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMRdEdgeLftgeometryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMRdEdgeRgtgeometryEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
                initResult = RMSMMessageEvent.Initialize();
                if (!initResult.HasValue()) {
                    break;
                }
            } while(false);

            return initResult;
        }
    private:
        ara::com::MethodCallProcessingMode processMode;
        std::unique_ptr<ara::com::internal::skeleton::SkeletonAdapter> ptr;
        events::TargetsInfoEvent TargetsInfoEvent;
        events::TargetInfoEvent TargetInfoEvent;
        events::RoadEdgeInfoEvent RoadEdgeInfoEvent;
        events::LaneMarkerInfoEvent LaneMarkerInfoEvent;
        events::RoadInfoEvent RoadInfoEvent;
        events::RMHeaderEvent RMHeaderEvent;
        events::IndexEvent IndexEvent;
        events::CarPositionEvent CarPositionEvent;
        events::LaneEvent LaneEvent;
        events::LaneMarkerEvent LaneMarkerEvent;
        events::ObjectEvent ObjectEvent;
        events::RoadEdgeEvent RoadEdgeEvent;
        events::NeighborLaneEvent NeighborLaneEvent;
        events::CorridorEvent CorridorEvent;
        events::SamplingPointEvent SamplingPointEvent;
        events::LineColorEvent LineColorEvent;
        events::LineTypeEvent LineTypeEvent;
        events::ObjectLocationEvent ObjectLocationEvent;
        events::SLPointEvent SLPointEvent;
        events::LaneControlEvent LaneControlEvent;
        events::LaneBoundryEvent LaneBoundryEvent;
        events::LineGeometryEvent LineGeometryEvent;
        events::RoadEdgeSegmentEvent RoadEdgeSegmentEvent;
        events::LaneInfoEvent LaneInfoEvent;
        events::LeftLineEvent LeftLineEvent;
        events::RightLineEvent RightLineEvent;
        events::RightRoadEdgeEvent RightRoadEdgeEvent;
        events::LeftRoadEdgeEvent LeftRoadEdgeEvent;
        events::ODDInfoEvent ODDInfoEvent;
        events::RMEgoLftLnegeometryEvent RMEgoLftLnegeometryEvent;
        events::RMEgoRgtLnegeometryEvent RMEgoRgtLnegeometryEvent;
        events::RMRdEdgeLftgeometryEvent RMRdEdgeLftgeometryEvent;
        events::RMRdEdgeRgtgeometryEvent RMRdEdgeRgtgeometryEvent;
        events::RMSMMessageEvent RMSMMessageEvent;
    };
    explicit EMServiceSkeleton(const ara::com::InstanceIdentifier& instanceId,
                           const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
        : skeletonAdapter(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceId, mode)),
          TargetsInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          TargetInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RoadEdgeInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneMarkerInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RoadInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMHeaderEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          IndexEvent(skeletonAdapter->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          CarPositionEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneMarkerEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          ObjectEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          NeighborLaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          CorridorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          SamplingPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LineColorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LineTypeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          ObjectLocationEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          SLPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneControlEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneBoundryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LineGeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RoadEdgeSegmentEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LaneInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LeftLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RightLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RightRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          LeftRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          ODDInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMEgoLftLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMEgoRgtLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMRdEdgeLftgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMRdEdgeRgtgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId),
          RMSMMessageEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceId){
        ConstructSkeleton(mode);
    }

    explicit EMServiceSkeleton(const ara::core::InstanceSpecifier& instanceSpec,
                           const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
        :skeletonAdapter(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec, mode)),
          TargetsInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          TargetInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RoadEdgeInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneMarkerInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RoadInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMHeaderEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          IndexEvent(skeletonAdapter->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          CarPositionEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneMarkerEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          ObjectEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          NeighborLaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          CorridorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          SamplingPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LineColorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LineTypeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          ObjectLocationEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          SLPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneControlEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneBoundryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LineGeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RoadEdgeSegmentEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LaneInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LeftLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RightLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RightRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          LeftRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          ODDInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMEgoLftLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMEgoRgtLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMRdEdgeLftgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMRdEdgeRgtgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec),
          RMSMMessageEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceSpec){
        ConstructSkeleton(mode);
    }

    explicit EMServiceSkeleton(const ara::com::InstanceIdentifierContainer instanceContainer,
                           const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
        :skeletonAdapter(std::make_unique<ara::com::internal::skeleton::SkeletonAdapter>(::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer, mode)),
          TargetsInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetsInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          TargetInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceTargetInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RoadEdgeInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneMarkerInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RoadInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMHeaderEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMHeaderEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          IndexEvent(skeletonAdapter->GetSkeleton(), events::EMServiceIndexEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          CarPositionEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCarPositionEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneMarkerEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneMarkerEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          ObjectEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          NeighborLaneEvent(skeletonAdapter->GetSkeleton(), events::EMServiceNeighborLaneEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          CorridorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceCorridorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          SamplingPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSamplingPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LineColorEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineColorEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LineTypeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineTypeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          ObjectLocationEvent(skeletonAdapter->GetSkeleton(), events::EMServiceObjectLocationEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          SLPointEvent(skeletonAdapter->GetSkeleton(), events::EMServiceSLPointEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneControlEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneControlEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneBoundryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneBoundryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LineGeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLineGeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RoadEdgeSegmentEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRoadEdgeSegmentEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LaneInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLaneInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LeftLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RightLineEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightLineEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RightRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRightRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          LeftRoadEdgeEvent(skeletonAdapter->GetSkeleton(), events::EMServiceLeftRoadEdgeEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          ODDInfoEvent(skeletonAdapter->GetSkeleton(), events::EMServiceODDInfoEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMEgoLftLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoLftLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMEgoRgtLnegeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMEgoRgtLnegeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMRdEdgeLftgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeLftgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMRdEdgeRgtgeometryEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMRdEdgeRgtgeometryEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer),
          RMSMMessageEvent(skeletonAdapter->GetSkeleton(), events::EMServiceRMSMMessageEventId, ::jac::ap::emservice::EMService::ServiceIdentifier, instanceContainer){
        ConstructSkeleton(mode);
    }

    EMServiceSkeleton(const EMServiceSkeleton&) = delete;

    EMServiceSkeleton(EMServiceSkeleton&&) = default;
    EMServiceSkeleton& operator=(EMServiceSkeleton&&) = default;
    EMServiceSkeleton(ConstructionToken&& token) noexcept
        : skeletonAdapter(token.GetSkeletonAdapter()),
          TargetsInfoEvent(token.GetTargetsInfoEvent()),
          TargetInfoEvent(token.GetTargetInfoEvent()),
          RoadEdgeInfoEvent(token.GetRoadEdgeInfoEvent()),
          LaneMarkerInfoEvent(token.GetLaneMarkerInfoEvent()),
          RoadInfoEvent(token.GetRoadInfoEvent()),
          RMHeaderEvent(token.GetRMHeaderEvent()),
          IndexEvent(token.GetIndexEvent()),
          CarPositionEvent(token.GetCarPositionEvent()),
          LaneEvent(token.GetLaneEvent()),
          LaneMarkerEvent(token.GetLaneMarkerEvent()),
          ObjectEvent(token.GetObjectEvent()),
          RoadEdgeEvent(token.GetRoadEdgeEvent()),
          NeighborLaneEvent(token.GetNeighborLaneEvent()),
          CorridorEvent(token.GetCorridorEvent()),
          SamplingPointEvent(token.GetSamplingPointEvent()),
          LineColorEvent(token.GetLineColorEvent()),
          LineTypeEvent(token.GetLineTypeEvent()),
          ObjectLocationEvent(token.GetObjectLocationEvent()),
          SLPointEvent(token.GetSLPointEvent()),
          LaneControlEvent(token.GetLaneControlEvent()),
          LaneBoundryEvent(token.GetLaneBoundryEvent()),
          LineGeometryEvent(token.GetLineGeometryEvent()),
          RoadEdgeSegmentEvent(token.GetRoadEdgeSegmentEvent()),
          LaneInfoEvent(token.GetLaneInfoEvent()),
          LeftLineEvent(token.GetLeftLineEvent()),
          RightLineEvent(token.GetRightLineEvent()),
          RightRoadEdgeEvent(token.GetRightRoadEdgeEvent()),
          LeftRoadEdgeEvent(token.GetLeftRoadEdgeEvent()),
          ODDInfoEvent(token.GetODDInfoEvent()),
          RMEgoLftLnegeometryEvent(token.GetRMEgoLftLnegeometryEvent()),
          RMEgoRgtLnegeometryEvent(token.GetRMEgoRgtLnegeometryEvent()),
          RMRdEdgeLftgeometryEvent(token.GetRMRdEdgeLftgeometryEvent()),
          RMRdEdgeRgtgeometryEvent(token.GetRMRdEdgeRgtgeometryEvent()),
          RMSMMessageEvent(token.GetRMSMMessageEvent()){
    }

    static ara::core::Result<ConstructionToken> Preconstruct(
        ara::com::InstanceIdentifier instanceId,
        const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
    {
        ConstructionToken token(instanceId, mode);
        const auto initResult = token.Initialize();
        ara::core::Result<ConstructionToken> result(std::move(token));
        if (!initResult.HasValue()) {
            const ara::core::ErrorCode errorCode(initResult.Error());
            result.EmplaceError(errorCode);
        }
        return result;
    }

    static ara::core::Result<ConstructionToken> Preconstruct(
        ara::core::InstanceSpecifier instanceSpec,
        const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
    {
        ConstructionToken token(instanceSpec, mode);
        const auto initResult = token.Initialize();
        ara::core::Result<ConstructionToken> result(std::move(token));
        if (!initResult.HasValue()) {
            const ara::core::ErrorCode errorCode(initResult.Error());
            result.EmplaceError(errorCode);
        }
        return result;
    }

    static ara::core::Result<ConstructionToken> Preconstruct(
        ara::com::InstanceIdentifierContainer instanceIdContainer,
        const ara::com::MethodCallProcessingMode mode = ara::com::MethodCallProcessingMode::kEvent)
    {
        ConstructionToken token(instanceIdContainer, mode);
        const auto initResult = token.Initialize();
        ara::core::Result<ConstructionToken> result(std::move(token));
        if (!initResult.HasValue()) {
            const ara::core::ErrorCode errorCode(initResult.Error());
            result.EmplaceError(errorCode);
        }
        return result;
    }

    virtual ~EMServiceSkeleton()
    {
        StopOfferService();
    }

    void OfferService()
    {
        skeletonAdapter->RegisterE2EErrorHandler(&EMServiceSkeleton::E2EErrorHandler, *this);
        skeletonAdapter->OfferService();
    }
    void StopOfferService()
    {
        skeletonAdapter->StopOfferService();
    }
    ara::core::Future<bool> ProcessNextMethodCall()
    {
        return skeletonAdapter->ProcessNextMethodCall();
    }
    bool SetMethodThreadNumber(const std::uint16_t& number, const std::uint16_t& queueSize)
    {
        return skeletonAdapter->SetMethodThreadNumber(number, queueSize);
    }

    virtual void E2EErrorHandler(ara::com::e2e::E2EErrorCode, ara::com::e2e::DataID, ara::com::e2e::MessageCounter){}

    events::TargetsInfoEvent TargetsInfoEvent;
    events::TargetInfoEvent TargetInfoEvent;
    events::RoadEdgeInfoEvent RoadEdgeInfoEvent;
    events::LaneMarkerInfoEvent LaneMarkerInfoEvent;
    events::RoadInfoEvent RoadInfoEvent;
    events::RMHeaderEvent RMHeaderEvent;
    events::IndexEvent IndexEvent;
    events::CarPositionEvent CarPositionEvent;
    events::LaneEvent LaneEvent;
    events::LaneMarkerEvent LaneMarkerEvent;
    events::ObjectEvent ObjectEvent;
    events::RoadEdgeEvent RoadEdgeEvent;
    events::NeighborLaneEvent NeighborLaneEvent;
    events::CorridorEvent CorridorEvent;
    events::SamplingPointEvent SamplingPointEvent;
    events::LineColorEvent LineColorEvent;
    events::LineTypeEvent LineTypeEvent;
    events::ObjectLocationEvent ObjectLocationEvent;
    events::SLPointEvent SLPointEvent;
    events::LaneControlEvent LaneControlEvent;
    events::LaneBoundryEvent LaneBoundryEvent;
    events::LineGeometryEvent LineGeometryEvent;
    events::RoadEdgeSegmentEvent RoadEdgeSegmentEvent;
    events::LaneInfoEvent LaneInfoEvent;
    events::LeftLineEvent LeftLineEvent;
    events::RightLineEvent RightLineEvent;
    events::RightRoadEdgeEvent RightRoadEdgeEvent;
    events::LeftRoadEdgeEvent LeftRoadEdgeEvent;
    events::ODDInfoEvent ODDInfoEvent;
    events::RMEgoLftLnegeometryEvent RMEgoLftLnegeometryEvent;
    events::RMEgoRgtLnegeometryEvent RMEgoRgtLnegeometryEvent;
    events::RMRdEdgeLftgeometryEvent RMRdEdgeLftgeometryEvent;
    events::RMRdEdgeRgtgeometryEvent RMRdEdgeRgtgeometryEvent;
    events::RMSMMessageEvent RMSMMessageEvent;
};
} // namespace skeleton
} // namespace emservice
} // namespace ap
} // namespace jac

#endif // JAC_AP_EMSERVICE_EMSERVICE_SKELETON_H
